* Addressing Mode Examples
*
* There are many ways to access data in memory.
* This example doesn't produce any practical output
* but does serve as to illustrate most of the ways
* in which we can use the addressing modes of the MC6809
* to access data. Examples here show Load (LDA) functions
* but all examples except the immediate addressing modes
* have equivalents for Store (STA) functions.
* I suggest you try it on the simulator for yourself.
*
*	M. Phythian	Aug 1997
*
	nam	addressing
two	equ	2	define a constant 2 (decimal)

	org	$0000
tab1	fcb	$01	define a table of values starting at $0000
	fcb	$02
	fcb	$03

	org	$1000
tab2	fcb	$10	define a table of values starting at $1000
	fcb	$20
	fcb	$30

	org	$8000
start	lda	tab1
* loads A with contents of $0000 using direct addressing
* if a fixed address in the instruction is within the DIRECT PAGE AREA
* defined by the Direct Page Register (default is DP = 00)
* then the instruction will use direct addressing mode,
* fetching the data from address DPxx.

	lda	#$10	
	tfr	a,dp	This is the way DP is be loaded
	lda	tab1
* loads A with contents of $1000 using direct addressing
* as the address in the instruction is within the DIRECT PAGE AREA
* defined by the Direct Page Register (ie DP = 10) 
* then the instruction will use direct addressing mode,
* fetching the data from address DPxx.

	lda	#$00	
	tfr	a,dp	Set DP back to 00 for rest of exmple
	lda	two
* loads A with the contents of $0002 using direct addressing
* this shows how to use a label instead of a number for the address.

	lda	tab2
* loads A with contents of $1000 using extended addressing
* if the fixed address in the instruction is outside of the DIRECT PAGE AREA
* then the instruction will use extended addressing mode,
* all extended addresses are 16 bits in the MC6809.

	lda	#two
* loads the constant value 2 into A using immediate addressing
* the # defines immediate mode. This is an 8 bit load.

	ldx	#tab2
* loads the address of tab2 ($1000) into X using immediate addressing
* the # defines immediate mode. This is a 16 bit load.

	lda	0,X	given X contains $1000
* loads A with the contents of $1000+0 (contents of X + the offset)
* using indexed addressing. X, Y, U or S can be used this way.
* The Effective Address (location being accessed) is $1000.

	lda	two,X
* loads A with the contents of $1000+2 (contents of X + the offset)
* using indexed addressing. In this case the effective address is $1002.

	ldb	#two	loads offset into B accumulator
	lda	B,X	assuming X still contains $1000
* loads A with the contents of $1000+2 (contents of X + the offset in B)
* using indexed addressing. In this case the effective address is $1002.

	ldx	#0000	Load a base address of $0000 into X
	lda	$1000,X	a 16 bit value can be used as an offset
* loads A with the contents of $0000+$1000 (contents of X + the offset)
* using indexed addressing. In this case the effective address is $1000.

	ldx	#0000	Load a base address of $0000 into X
	lda	tab2,X	the value/label tab2 can be used as a 16 bit offset
* loads A with the contents of $0000+$1000 (contents of X + the offset)
* using indexed addressing. In this case the effective address is $1000.
* other examples in the study guide illustrate more on indexed addressing

	lda	#two
	inca
	lsla
* the last two instructions use inherent addressing mode
* sometimes called 'implied' this means the address is known to the
* microprocessor and does not need to be specified in the instruction.
* There is no address for accumulator A, it is part of the MPU.
	
* the other addressing mode you will see refered to in the data sheets
* is the 'relative' addressing mode. This is used for branch instructions
* although there is a form of indexed addressing called PC relative.
* In all my years of programming I have only used PC relative twice.
	end
